==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/ja.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "コメント",
    "Edit comment" : "コメントを編集",
    "Delete comment" : "コメントを削除",
    "New comment …" : "新しいコメント...",
    "Post" : "追加",
    "Cancel" : "キャンセル",
    "[Deleted user]" : "[削除済みユーザー]",
    "No comments yet, start the conversation!" : "まだコメントはありません、会話を開始してください！",
    "More comments …" : "その他のコメント...",
    "Save" : "保存",
    "Allowed characters {count} of {max}" : "入力文字数  {count} / {max}",
    "Error occurred while retrieving comment with ID {id}" : "ID {id} のコメント取得中にエラーが発生しました",
    "Error occurred while updating comment with id {id}" : "ID {id} のコメント更新中にエラーが発生しました",
    "Error occurred while posting comment" : "コメント投稿中にエラーが発生しました",
    "_%n unread comment_::_%n unread comments_" : ["%n の未読のコメント"],
    "Comment" : "コメント",
    "You commented" : "コメント済",
    "%1$s commented" : "%1$s がコメントを追加",
    "{author} commented" : "{author} がコメントしました",
    "You commented on %1$s" : "%1$s にコメントしました",
    "You commented on {file}" : "{file} にコメントしました",
    "%1$s commented on %2$s" : "%2$s について、%1$s がコメントしました",
    "{author} commented on {file}" : "{author} が{file} にコメントしました",
    "<strong>Comments</strong> for files" : "ファイルへの<strong>コメント</strong>があったとき",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s さんが “%2$s” のコメントであなたについて言及しました。",
    "{user} mentioned you in a comment on “{file}”" : "{user} さんが ““{file}” のコメントであなたについて言及しました。",
    "Unknown user" : "不明なユーザー",
    "A (now) deleted user mentioned you in a comment on “%s”" : "(現在)削除されたユーザーが \"%s\" のコメントであなたのことについて言及しました",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "(現在)削除されたユーザーが \"{file}\" のコメントであなたのことについて言及しました"
},
"nplurals=1; plural=0;");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/ja.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "コメントを編集",
    "Delete comment" : "コメントを削除",
    "New comment …" : "新しいコメント...",
    "Post" : "追加",
    "Cancel" : "キャンセル",
    "[Deleted user]" : "[削除済みユーザー]",
    "Comments" : "コメント",
    "No comments yet, start the conversation!" : "まだコメントはありません、会話を開始してください！",
    "More comments …" : "その他のコメント...",
    "Save" : "保存",
    "Allowed characters {count} of {max}" : "入力文字数  {count} / {max}",
    "Error occurred while retrieving comment with ID {id}" : "ID {id} のコメント取得中にエラーが発生しました",
    "Error occurred while updating comment with id {id}" : "ID {id} のコメント更新中にエラーが発生しました",
    "Error occurred while posting comment" : "コメント投稿中にエラーが発生しました",
    "_%n unread comment_::_%n unread comments_" : ["%n の未読のコメント"],
    "Comment" : "コメント",
    "You commented" : "コメント済",
    "%1$s commented" : "%1$s がコメントを追加",
    "{author} commented" : "{author} がコメントしました",
    "You commented on %1$s" : "%1$s にコメントしました",
    "You commented on {file}" : "{file} にコメントしました",
    "%1$s commented on %2$s" : "%2$s について、%1$s がコメントしました",
    "{author} commented on {file}" : "{author} が{file} にコメントしました",
    "<strong>Comments</strong> for files" : "ファイルへの<strong>コメント</strong>があったとき",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "削除されたユーザーのコメントで \"{file}\" にあなたに言及しました",
    "{user} mentioned you in a comment on “{file}”" : "{user} さんが ““{file}” のコメントであなたについて言及しました。",
    "Files app plugin to add comments to files" : "ファイルにコメントを追加するためのファイルアプリプラグイン",
    "Unknown user" : "不明なユーザー",
    "A (now) deleted user mentioned you in a comment on “%s”" : "(現在)削除されたユーザーが \"%s\" のコメントであなたのことについて言及しました",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "(現在)削除されたユーザーが \"{file}\" のコメントであなたのことについて言及しました",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s さんが “%2$s” のコメントであなたについて言及しました。",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "削除されたユーザーのコメントで %s にあなたに言及しました"
},
"nplurals=1; plural=0;");
